@@ -219,8 +219,8 @@ bool fullscreen=false;
 
 	CheckCdrom();
 
-	/*if (file != NULL) Load(file);
-	else*/
+	//if (file != NULL) Load(file);
+	//else
 	{
 		if (runcd == 1) {
 			LoadCdBios = 0;
@@ -238,26 +238,22 @@ bool fullscreen=false;
 		}
 	}
 
-	if (loadst)
-	{
-    __saved = 1;
-		sprintf (save_filename, "%s", loadst);
-		LoadState(save_filename);
-	}
+
+	
+printf ("Started\n");
 
 #ifdef MAEMO_CHANGES
-/*
+
+#ifndef PEOPS_GPU
 	printf(
 		"CdromFile: %s\n"
-#ifndef PEOPS_GPU
+
 		"Show FPS                 %s\n"
 #endif
 #if defined(ENABLE_GPU_PRIM_STATS) || defined(ENABLE_GPU_PROFILLER)
 		"Show GPU Stats           %s\n"
 #endif
-#ifndef PEOPS_GPU
 		"Display Video Memory     %s\n"
-#endif
 		"Set NULL GPU             %s\n"
 		"Interlace Count          %d\n"
 		"Frame Limit              %s\n"
@@ -266,18 +262,16 @@ bool fullscreen=false;
 		"Abe's Oddysee Fix        %s\n"
 		"Sound                    %s\n"
 		"Fullscreen               %s\n",
-		
 		file,
-#ifndef PEOPS_GPU
+
 		(displayFrameInfo == false ? "OFF" : "ON"),
-#endif
+
 #if defined(ENABLE_GPU_PRIM_STATS) || defined(ENABLE_GPU_PROFILLER)
 		(displayGpuStats == false ? "OFF" : "ON"),
 #endif
-#ifndef PEOPS_GPU
+
 		(displayVideoMemory == false ? "OFF" : "ON"),
-#endif
-#ifndef PEOPS_GPU
+
 		(activeNullGPU == false ? "OFF" : "ON"),
 		linesInterlace_user,
 		(enableFrameLimit == false ? "OFF" : "ON"),
@@ -287,9 +281,10 @@ bool fullscreen=false;
 		
 		(iSoundMuted == 0 ? "ON" : "OFF"),
 		(fullscreen == true ? "ON" : "OFF")
+
 	);
-	*/
-#endif
+	#endif
+
 
 	psxCpu->Execute();
 	return 0;
