@@ -104,18 +104,18 @@ void psxRcntInit() {
 
 void psxUpdateVSyncRate() {
 	if (Config.PsxType) // ntsc - 0 | pal - 1
-	     psxCounters[3].rate = (PSXCLK / 50);// / BIAS;
-	else psxCounters[3].rate = (PSXCLK / 60);// / BIAS;
-	psxCounters[3].rate-= (psxCounters[3].rate / 262) * 22;
-	if (Config.VSyncWA) psxCounters[3].rate/= 2;
+	     psxCounters[3].rate = (PSXCLK / 50)/ BIAS;// / BIAS;
+	else psxCounters[3].rate = (PSXCLK / 60)/ BIAS;// / BIAS;
+	//psxCounters[3].rate-= (psxCounters[3].rate / 262) * 22;
+	if (Config.VSyncWA)psxCounters[3].rate/= 2;
 }
 
 void psxUpdateVSyncRateEnd() {
 	if (Config.PsxType) // ntsc - 0 | pal - 1
-	     psxCounters[3].rate = (PSXCLK / 50);
-	else psxCounters[3].rate = (PSXCLK / 60);
-	psxCounters[3].rate = (psxCounters[3].rate / 262) * 22;
-	if (Config.VSyncWA) psxCounters[3].rate/= 2;
+	     psxCounters[3].rate = (PSXCLK / 50)/ BIAS;
+	else psxCounters[3].rate = (PSXCLK / 60)/ BIAS;
+	//psxCounters[3].rate = (psxCounters[3].rate / 262) * 22;
+	if (Config.VSyncWA)	psxCounters[3].rate/= 2;
 }
 
 extern u32		isInBios;
