@@ -367,10 +367,11 @@ void  gpuSkipUpdate()
       linesInterlace = linesInterlace_user;
       gp2x_video_RGB_clearscreen16();
     }
-  }
-  curFlip  = gp2x_timer_raw()-curFlip;
+	
+	
+	  curFlip  = gp2x_timer_raw()-curFlip;
 
-  if(displayFrameInfo && (!isSkip))
+  if(displayFrameInfo)
   {
     int ypos = 0;
     //gp2x_printf(NULL, 0, ypos,"VS:%04.4g fps:NA real:NA fs(%d/%d) (%3d,%2d,%2d)ms", float(vsincRate)/100.0f, skipCount, skipRate, gp2x_timer_raw_to_ticks(curFrame),gp2x_timer_raw_to_ticks(curFlip),gp2x_timer_raw_to_ticks(curDelay));
@@ -395,6 +396,8 @@ void  gpuSkipUpdate()
     }
   #endif
   }
+  }
+
   PROFILE_RESET(gpuPolyTime,gpuPolyCount);
   PROFILE_RESET(gpuRasterTime,gpuRasterCount);
   PROFILE_RESET(gpuPixelTime,gpuPixelCount);
@@ -408,6 +411,7 @@ void  gpuSkipUpdate()
 
   s_LastFrame = gp2x_timer_raw();
 
+  if (!autoSkip){
   if(skCount-->0)
   {
     isSkip = 1;
@@ -421,7 +425,7 @@ void  gpuSkipUpdate()
   {
     skCount = Min2(skipCount,skipRate?skipRate-1:0);
     skRate  = skipRate;
-  }
+  }}
 }
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -511,24 +515,33 @@ void  NEWGPU_vSinc(void)
     frameRate = (u64)(frameRateCounter*100)*gp2x_timer_raw_second() / diffintime;
     realRate  = (u64)(frameRealCounter*100)*gp2x_timer_raw_second() / diffintime;
 
-    if(enableFrameLimit && frameRate)
-    {
+	//  if (autoSkip){
+  // Experemental auto frameskip
+ // if (vsincRate)isSkip = 1;else isSkip = 0;
+ // }
+  
+  //  if(enableFrameLimit && frameRate)
+    if (autoSkip){
       int inc    = gp2x_timer_raw_second() > 1000 ? gp2x_timer_raw_second()/5000 : gp2x_timer_raw_second()/1000;
-      int target =(isPAL==0 ? 60 : 50) * 100;
-      int range  = target*5/100;
+      int target =(isPAL==0 ? 6600 : 5500);
 
-      if(vsincRate>(target+range))
+
+      if(vsincRate>target)
       {
         curDelay_inc = (curDelay_inc>0) ? (curDelay_inc+inc) : (-curDelay_inc);
         curDelay    += curDelay_inc;
+		isSkip = 0;
       }
       else
-      if(vsincRate<(target-range))
+     // if(vsincRate<(target+range))
       {
-        curDelay_inc = (curDelay_inc<0) ? (curDelay_inc-inc) : (-curDelay_inc);
-        curDelay    += curDelay_inc;
+        //curDelay_inc = (curDelay_inc<0) ? (curDelay_inc-inc) : (-curDelay_inc);
+        //curDelay    += curDelay_inc;
+		isSkip = 1;
+		curDelay=0;
       }
     }
+	
     vsincRateCounter = 0;
 		frameRateCounter = 0;
 		frameRealCounter = 0;
