@@ -192,8 +192,11 @@ void gp2x_change_res(int w, int h)
 	image = gdk_image_new( GDK_IMAGE_FASTEST, gdk_visual_get_system(), w, h );
 
 	screenbuffer = (unsigned short*) image->mem;
+	#ifndef PEOPS_GPU
 	screen_size = image->bpl * (h / (linesInterlace_user+1)) * image->bpp;
-
+	#else
+	screen_size = image->bpl * h * image->bpp;
+#endif
 	gtk_image_set_from_image (GTK_IMAGE(drawing), image, NULL);
 
 	gtk_window_resize (GTK_WINDOW (actor), w, h);
